==> coin2_2.3.0.orig.tar.gz: Coin-2.3.0/include/Inventor/misc/SoAuditorList.h <==
#ifndef COIN_MISC_SOAUDITORLIST_H
#define COIN_MISC_SOAUDITORLIST_H

/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2004 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See <URL:http://www.coin3d.org/> for more information.
 *
 *  Systems in Motion, Teknobyen, Abels Gate 5, 7030 Trondheim, NORWAY.
 *  <URL:http://www.sim.no/>.
 *
\**************************************************************************/

// NB: make sure the ifdef-test above wrapping this includefile is
// _not_ checking on and setting the same define-string as the other
// SoAuditorList.h file in the include/Inventor/lists/ directory.

// This include file is part of the Coin library solely for purposes
// of being backwards compatible with Open Inventor.

// The real class definition include file has been moved to the lists
// directory.
#include <Inventor/lists/SoAuditorList.h>

#endif // !COIN_MISC_SOAUDITORLIST_H

==> coin2_2.4.4.orig.tar.gz: Coin-2.4.4/include/Inventor/misc/SoAuditorList.h <==
#ifndef COIN_MISC_SOAUDITORLIST_H
#define COIN_MISC_SOAUDITORLIST_H

/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2005 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See <URL:http://www.coin3d.org/> for more information.
 *
 *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
 *  <URL:http://www.sim.no/>.
 *
\**************************************************************************/

// NB: make sure the ifdef-test above wrapping this includefile is
// _not_ checking on and setting the same define-string as the other
// SoAuditorList.h file in the include/Inventor/lists/ directory.

// This include file is part of the Coin library solely for purposes
// of being backwards compatible with Open Inventor.

// The real class definition include file has been moved to the lists
// directory.
#include <Inventor/lists/SoAuditorList.h>

#endif // !COIN_MISC_SOAUDITORLIST_H
